///////////////////////////////////////////////////////////////////////////////
//                                                                           //
// Class: UDControlBinder.uc                                                 //
// Author: Dan Weiss                                                         //
// Date: June 2006                                                           //
// Purpose: This class handles the input section of the controls menu as a   //
//     new custom version for Unreal Demolition.                             //
//                                                                           //
///////////////////////////////////////////////////////////////////////////////

class UDControlBinder extends KeyBindMenu;

var localized string BindingLabel[150];

function LoadCommands()
{
	local int i;

	Super.LoadCommands();

	// Update the MultiColumnList's sortdata array to reflect the indexes of our Bindings array
    for (i = 0; i < Bindings.Length; i++)
    	li_Binds.AddedItem();
}

function MapBindings()
{
	LoadCustomBindings();
	Super.MapBindings();
}

protected function LoadCustomBindings()
{
	local int i;
	local array<string> KeyBindClasses;
    local class<GUIUserKeyBinding> CustomKeyBindClass;

    // Load custom keybinds from .int files
    PlayerOwner().GetAllInt("XInterface.GUIUserKeyBinding",KeyBindClasses);
	for (i = 0; i < KeyBindClasses.Length; i++)
	{
		CustomKeyBindClass = class<GUIUserKeyBinding>(DynamicLoadObject(KeyBindClasses[i],class'Class'));
		if (CustomKeyBindClass != None)
			AddCustomBindings( CustomKeyBindClass.default.KeyData );
    }
}

function AddCustomBindings( array<GUIUserKeyBinding.KeyInfo> KeyData )
{
	local int i;

	for ( i = 0; i < KeyData.Length; i++ )
		CreateAliasMapping( KeyData[i].Alias, KeyData[i].KeyLabel, KeyData[i].bIsSection );
}

function ClearBindings()
{
	local int i, max;

	Super.ClearBindings();
	Bindings = default.Bindings;
	max = Min(Bindings.Length, ArrayCount(BindingLabel));
	for ( i = 0; i < max; i++ )
	{
		if ( BindingLabel[i] != "" )
			Bindings[i].KeyLabel = BindingLabel[i];
	}
}

defaultproperties
{
	PageCaption="Configure Unreal Demolition Controls"
	Headings(0)="Action"
    Bindings(0)=(bIsSectionLabel=true,KeyLabel="Movement")
    BindingLabel(0)="Movement"
    Bindings(1)=(KeyLabel="Forward",Alias="MoveForward")
    BindingLabel(1)="Forward"
    Bindings(2)=(KeyLabel="Backward",Alias="MoveBackward")
    BindingLabel(2)="Backward"
    Bindings(3)=(KeyLabel="Turn Left",Alias="StrafeLeft")
    BindingLabel(3)="Turn Left"
    Bindings(4)=(KeyLabel="Turn Right",Alias="StrafeRight")
    BindingLabel(4)="Turn Right"
    Bindings(5)=(KeyLabel="Boost",Alias="AltFire")
    BindingLabel(5)="Boost"

    Bindings(6)=(bIsSectionLabel=true,KeyLabel="Stunts")
    BindingLabel(6)="Stunts"
    Bindings(7)=(KeyLabel="Barrel Roll Left",Alias="UDBarrelRoll 0 true | OnRelease UDBarrelRoll 0 false")
    BindingLabel(7)="Barrel Roll Left"
    Bindings(8)=(KeyLabel="Barrel Roll Right",Alias="UDBarrelRoll 1 true | OnRelease UDBarrelRoll 1 false")
    BindingLabel(8)="Barrel Roll Right"
    Bindings(9)=(KeyLabel="Jump",Alias="Fire")
    BindingLabel(9)="Jump"
    Bindings(10)=(KeyLabel="Back Flip",Alias="Jump")
    BindingLabel(10)="Back Flip"
    Bindings(11)=(KeyLabel="Front Flip",Alias="Duck")
    BindingLabel(11)="Front Flip"

    Bindings(12)=(bIsSectionLabel=true,KeyLabel="Other")
    BindingLabel(12)="Other"
    Bindings(13)=(KeyLabel="Normal Horn",Alias="playvehiclehorn 0")
    BindingLabel(13)="Normal Horn"
    Bindings(14)=(KeyLabel="Dixie Horn",Alias="playvehiclehorn 1")
    BindingLabel(14)="Dixie Horn"
    Bindings(15)=(KeyLabel="Switch View",Alias="ToggleBehindView")
    BindingLabel(15)="Switch View"
}
