
class UDSumo extends xLastManStandingGame;

#exec OBJ LOAD FILE=UDHUD.utx

var(LoadingHints) private localized array<string> UDHints;

function RestartPlayer( Controller aPlayer )
{
    Super.RestartPlayer(aPlayer);
    SpawnVehicle(aPlayer.Pawn);
}

// Override the last man standing inventory fulling out
// so rocket launchers does not spawn ...
function AddGameSpecificInventory(Pawn p)
{
}

function SpawnVehicle(Pawn P)
{
    local Vehicle EntryVehicle, V;

    if (P == none)
       return;

    //Used to hold data for spawning multiple vehicles.
    //Erased for time being until multi vehicles are replaced.
    if (P.PlayerReplicationInfo != None)
    {
        V = spawn(class'UDBike',,,P.Location, P.Rotation);
    }
    else // choose UDBike if no PRI
    {
        V = spawn(class'UDBike',,,P.Location, P.Rotation);
    }

    if (V != none)
    {
        // Sets the PreviousVehicleClass, needed to check what vehicle the player had last time
        if (P.PlayerReplicationInfo != None)
            UDPRI(P.PlayerReplicationInfo).PreviousVehicleClass = V.class;
        if (PlayerController(P.Controller) != None)
        {
                if (PlayerController(P.Controller).bBehindView == false)
                {
                        PlayerController(P.Controller).ToggleBehindView();
                        PlayerController(P.Controller).BehindView(True);
                }
        }

        // Copied code from PlayerController.ServerUse()
        EntryVehicle = V.FindEntryVehicle(P);
        if (EntryVehicle != None && EntryVehicle.TryToDrive(P))
                       return;

        V.UsedBy(P);
        if ( P.Base != None )
                     P.Base.UsedBy(P);

        P.Health-=1;
        P.Health+=1;

    }
    else
        log ("BUG: NO VEHICLE!");
}

// New bot class needed to give bots new PRI with PreviousVehicleClass
function Bot SpawnBot(optional string botName)
{
    local Bot NewBot;
    local RosterEntry Chosen;
    local UnrealTeamInfo BotTeam;

    BotTeam = GetBotTeam();
    Chosen = BotTeam.ChooseBotClass(botName);

    if (Chosen.PawnClass == None)
        Chosen.Init(); //amb
    NewBot = Spawn(Class'UDBot');

    if ( NewBot != None )
        InitializeBot(NewBot,BotTeam,Chosen);
    return NewBot;
}

function Logout(Controller Exiting)
{
    local UDVech DrivenVehicle;

    Super.Logout(Exiting);

    if (Exiting.Pawn != None)
           DrivenVehicle = UDVech(Exiting.Pawn);

    if ( DrivenVehicle != None )
    {
         DrivenVehicle.KDriverLeave(true); // Force the driver out of the car
         DrivenVehicle.Destroy();
    }
}

// Only line changed is the Score += 5
function ScoreKill(Controller Killer, Controller Other)
{
    local PlayerReplicationInfo OtherPRI;

    if ( (killer == None) && (Other == None) )
        return;

    OtherPRI = Other.PlayerReplicationInfo;
    if ( OtherPRI != None )
    {
        OtherPRI.NumLives++;
        if ( (MaxLives > 0) && (OtherPRI.NumLives >=MaxLives) )
            OtherPRI.bOutOfLives = true;
    }

    if ( bAllowTaunts && (Killer != None) && (Killer != Other) && Killer.AutoTaunt()
        && (Killer.PlayerReplicationInfo != None) && (Killer.PlayerReplicationInfo.VoiceType != None) )
    {
        if( Killer.IsA('PlayerController') )
            Killer.SendMessage(OtherPRI, 'AUTOTAUNT', Killer.PlayerReplicationInfo.VoiceType.static.PickRandomTauntFor(Killer, false, false), 10, 'GLOBAL');
        else
            Killer.SendMessage(OtherPRI, 'AUTOTAUNT', Killer.PlayerReplicationInfo.VoiceType.static.PickRandomTauntFor(Killer, false, true), 10, 'GLOBAL');
    }

    if ( ((Killer == Other) || (Killer == none)) && Other != none )
    {
        //for sumo, no points off for "suicide", aka knocked out
        //in order to prevent any conflicts with collision not
        //registering
        Other.PlayerReplicationInfo.Score += 0;
        scoreEvent(Other.PlayerReplicationInfo, 0, "self_frag");
    }
    else if (Killer.PlayerReplicationInfo != none)
    {
        //+3 point for stomp kills
        //+5 points for knockout kills (not done yet)
        Killer.PlayerReplicationInfo.Kills++;
        Killer.PlayerReplicationInfo.Score += 3;
        ScoreEvent(Killer.PlayerReplicationInfo, 1, "frag");
    }
    if (gameRulesModifiers != none)
        gameRulesModifiers.scoreKill(Killer, Other);

    if ( (Killer != None) || (MaxLives > 0) )
        CheckScore(Killer.PlayerReplicationInfo);

    if ( (killer == None) || (Other == None) )
        return;

    if ( bAdjustSkill && (killer.IsA('PlayerController') || Other.IsA('PlayerController')) )
    {
        if ( killer.IsA('AIController') )
            AdjustSkill(AIController(killer), PlayerController(Other),true);
        if ( Other.IsA('AIController') )
            AdjustSkill(AIController(Other), PlayerController(Killer),false);
    }
}

// JeT Says: We want our own custom hints dammit!
static function array<string> GetAllLoadHints(optional bool bThisClassOnly)
{
    local int i;
    local array<string> Hints;

    for ( i = 0; i < default.UDHints.Length; i++ )
        Hints[Hints.Length] = default.UDHints[i];

    return Hints;
}

// Changed 1 line because of accessed none :/ (Accessed None 'Pawn')
State MatchInProgress
{
    // GameInfo's already have a 1 second timer...
    function Timer()
    {
        local int i,j;
        local Box HistoryBox;
        local float MaxDim;
        local bool bSentWarning;

        Super(xDeathMatch).Timer();

        // Do nothing else if camper alarm is off.
        if(!bCamperAlarm)
            return;

        i=0;
        while(i < LMSData.Length && !bSentWarning)
        {
            //Log( "Checking: "$LMSData[i].PC.PlayerReplicationInfo.PlayerName );

            // If controller has expired (eg. left the game), remove the guard.
            if( LMSData[i].PC == None )
            {
                //Log("Expiring Camper Guard.");
                LMSData.Remove(i, 1);
            }
            else if( !LMSData[i].PC.PlayerReplicationinfo.bIsSpectator && !LMSData[i].PC.PlayerReplicationinfo.bOnlySpectator && LMSData[i].PC.PlayerReplicationInfo.NumLives<MaxLives && LMSData[i].PC.Pawn != None) // Spectators can't camp
            {
                // Always update
                LMSData[i].LocationHistory[LMSData[i].NextLocHistSlot] = LMSData[i].PC.Pawn.Location;
                LMSData[i].NextLocHistSlot++;

                if(LMSData[i].NextLocHistSlot == 10)
                {
                    LMSData[i].NextLocHistSlot = 0;
                    LMSData[i].bWarmedUp = true;
                }

                // If our history is full, work out how much player is moving about (find max AABB dimension).
                if(LMSData[i].bWarmedUp)
                {
                    HistoryBox.Min.X = LMSData[i].LocationHistory[0].X;
                    HistoryBox.Min.Y = LMSData[i].LocationHistory[0].Y;
                    HistoryBox.Min.Z = LMSData[i].LocationHistory[0].Z;

                    HistoryBox.Max.X = LMSData[i].LocationHistory[0].X;
                    HistoryBox.Max.Y = LMSData[i].LocationHistory[0].Y;
                    HistoryBox.Max.Z = LMSData[i].LocationHistory[0].Z;

                    for(j=1; j<10; j++)
                    {
                        HistoryBox.Min.X = FMin( HistoryBox.Min.X , LMSData[i].LocationHistory[j].X );
                        HistoryBox.Min.Y = FMin( HistoryBox.Min.Y , LMSData[i].LocationHistory[j].Y );
                        HistoryBox.Min.Z = FMin( HistoryBox.Min.Z , LMSData[i].LocationHistory[j].Z );

                        HistoryBox.Max.X = FMax( HistoryBox.Max.X , LMSData[i].LocationHistory[j].X );
                        HistoryBox.Max.Y = FMax( HistoryBox.Max.Y , LMSData[i].LocationHistory[j].Y );
                        HistoryBox.Max.Z = FMax( HistoryBox.Max.Z , LMSData[i].LocationHistory[j].Z );
                    }

                    // Find maximum dimension of box
                    MaxDim = FMax(FMax(HistoryBox.Max.X - HistoryBox.Min.X, HistoryBox.Max.Y - HistoryBox.Min.Y), HistoryBox.Max.Z - HistoryBox.Min.Z);

                    //Log("Box: "$HistoryBox.Max.X@HistoryBox.Max.Y@HistoryBox.Max.Z@HistoryBox.Min.X@HistoryBox.Min.Y@HistoryBox.Min.Z);
                    //Log("Player: "$LMSData[i].PC.PlayerReplicationInfo.PlayerName$" MaxDim:"$MaxDim);

                    // Dont warn the same person every second!
                    if(MaxDim < CampThreshold && LMSData[i].ReWarnTime == 0)
                    {
                        //Log(LMSData[i].PC.PlayerReplicationInfo.PlayerName$" IS CAMPING! "$MaxDim);
                        SendCamperWarning(LMSData[i].PC);
                        LMSData[i].ReWarnTime = ReCamperWarnInterval;
                        bSentWarning=true;
                    }
                    else if(LMSData[i].ReWarnTime > 0)
                        LMSData[i].ReWarnTime--;
                }

                i++;
            }
            else
                i++;
        }
    }
}

defaultproperties
{
     UDHints(0)="Press %LEFT% or %RIGHT% to make your vehicle spin in mid-air."
     UDHints(1)="Press %CROUCH% or %JUMP% to make your vehicle flip in mid-air."
     UDHints(2)="Press [Roll Left] or [Roll right] to perform barrel rolls."
     UDHints(3)="Press %JUMP% while on the ground to activate the handbrake."
     UDHints(4)="Press %FIRE% to perform a jump. while in the air %FIRE% will make your vehicle stomp back to the ground."
     UDHints(5)="Press %NEXTWEAPON% and %PREVWEAPON% to control the vehicle's camera zoom."
     UDHints(6)="Pressing %ALTFIRE% will give you a sudden burst of speed."
     UDHints(7)="Jumping and Boosting uses up your PSI. If you run out you'll be sorry."
     UDHints(8)="Pick up PSI and Armor pickups to improve your vehicle and live longer."
     UDHints(9)="%ALTFIRE% will flip your vehicle if you land on your back."
     UDHints(10)="Pressing %ALTFIRE% repeatedly while your vehicle isn't upright will make your vehicle dance."
     UDHints(11)="You can set what keys you can perform barrel rolls with in your input settings."
     UDHints(12)="Killing other players will give you bonus points."
     UDHints(13)="Trying to get too far out of a map can result in the blowing up of your vehicle."
     bAllowVehicles=True
     ScoreBoardType="UnrealDemolition.UDScoreBoard"
     HUDType="UnrealDemolition.UDHUD"
     MapPrefix="UDSU"
     BeaconName="UDSU"
     GoalScore=60
     MaxLives=10
     TimeLimit=20
     DeathMessageClass=Class'UnrealDemolition.UDDeathMessage'
     MutatorClass="UnrealDemolition.UDMutSumo"
     PlayerControllerClassName="UnrealDemolition.UDPlayer"
     GameName="UD Sumo"
     Description="Using sumo tactics of knocking your opponent out of the arena, last the longest to win the battle."
     ScreenShotName="UDHUD.intro.udsuintro"
     Acronym="UDSU"
}
