; UnrealDemolition.nsi

; MODERN UI
!include "MUI.nsh"
!include "LogicLib.nsh"

Name "UnrealDemolition"
OutFile "UnrealDemolitionPB4.exe"
SetCompressor LZMA

; This will try to automatically detect your UT2004 installation, if not found it suggests C:\UT2004
InstallDir "C:\UT2004"
InstallDirRegKey HKLM "Software\Unreal Technology\Installed Apps\UT2004" "Folder"

; INTERFACE SETTINGS 
; The MODERN UI needs this 
!define MUI_HEADERIMAGE
!define MUI_HEADERIMAGE_BITMAP_NOSTRETCH
!define MUI_ABORTWARNING

; PAGES
; The pages the setup will have.
!insertmacro MUI_PAGE_LICENSE "..\UnrealDemolition\UDreadme.txt" ; Your Readme/Licence Agreement
!insertmacro MUI_PAGE_COMPONENTS
!insertmacro MUI_PAGE_DIRECTORY
!insertmacro MUI_PAGE_INSTFILES
!insertmacro MUI_UNPAGE_CONFIRM
!insertmacro MUI_UNPAGE_INSTFILES
!insertmacro MUI_LANGUAGE "English"

; Startmenu shortcuts.

; SECTIONS
Section "UnrealDemolition" UnrealDemolition

ReadINIStr $R0 "$INSTDIR\System\UT2004.ini" "FirstRun" "FirstRun"
DetailPrint "Detected UT Version:"
DetailPrint $R0

${Switch} $R0

  ${Case} "3369"
	Messagebox MB_OK|MB_ICONINFORMATION \
	"UT2004 version check successfull."
	${Break}	
  ${Case} "0"
	Messagebox MB_OK|MB_ICONINFORMATION \
	"No Version Information (Version 0 reported). You should start UT2004 at least once before installing MyMod."
	${Break}
  ${Case} ""
	Messagebox MB_OK|MB_ICONINFORMATION \
	"No UT version detected! (Could not find UT2004.ini)"
	${Break}
  ${Default}
  	Messagebox MB_YESNO|MB_ICONINFORMATION \
	"Your UT Version is unknown or outdated! Update to 3369 now?" \
	IDYES patch IDNO nopatch	

${EndSwitch}

Goto nopatch

  patch: 
  ; This will download the 3369 patch (if neccessary) from yoururl.com
  ; You have to provide a direct download mirror here. 
    NSISdl::download http://www.unrealdemolition.net/Files/ut2004-winpatch3369.exe
    ; Setup will wait until patching is done and then continue
    ExecWait "$INSTDIR\ut2004-winpatch3369.exe"
    Goto nopatch
  nopatch:

SetOutPath "$INSTDIR\UnrealDemolition\Help"
File ..\UnrealDemolition\Help\UnrealDemolitionLogo.BMP
SetOutPath "$INSTDIR\UnrealDemolition\Maps"
File ..\UnrealDemolition\Maps\*.*
SetOutPath "$INSTDIR\UnrealDemolition\Sounds"
File ..\UnrealDemolition\Sounds\*.*
SetOutPath "$INSTDIR\UnrealDemolition\StaticMeshes"
File ..\UnrealDemolition\StaticMeshes\*.*
SetOutPath "$INSTDIR\UnrealDemolition\System"
File ..\UnrealDemolition\System\*.*
SetOutPath "$INSTDIR\UnrealDemolition\Textures"
File ..\UnrealDemolition\Textures\*.*
SetOutPath "$INSTDIR\UnrealDemolition\"
File ..\UnrealDemolition\UT2K4Mod.ini
File ..\UnrealDemolition\UDreadme.txt
SectionEnd

Section "" Main
CreateDirectory "$SMPROGRAMS\UnrealDemolition"
CreateShortCut "$SMPROGRAMS\UnrealDemolition\UnrealDemolition.lnk"  "$INSTDIR\System\UT2004.exe -mod=UnrealDemolition" "" "$INSTDIR\Help\Unreal.ico"
CreateShortCut "$SMPROGRAMS\UnrealDemolition\Uninstall.lnk"  "$INSTDIR\UnrealDemolition\Uninstall.exe"
; Uninstaller
WriteUninstaller "$INSTDIR\UnrealDemolition\Uninstall.exe"

; Add the following to the Main Section:
; THIS IS OPTIONAL!
; It will make UnrealDemolition start when UnrealDemolition://ip is called instead of ut2004://ip
WriteRegStr HKCR "UnrealDemolition" "" "URL:Unreal Tournament 2004 Protocol"
WriteRegStr HKCR "UnrealDemolition" "URL Protocol" ""
WriteRegStr HKCR "UnrealDemolition\DefaultIcon" "" "$INSTDIR\Help\Unreal.ico"
WriteRegStr HKCR "UnrealDemolition\shell" "" "open"
WriteRegStr HKCR "UnrealDemolition\shell\open" "" "&Play UnrealDemolition"
WriteRegStr HKCR "UnrealDemolition\shell\open\command" "" '$INSTDIR\System\UT2004.exe "%1" -mod=UnrealDemolition'

SectionEnd

LangString DESC_UnrealDemolition ${LANG_ENGLISH} "Unreal Demolition Core (required) - The files you need to play Unreal Demolition."
!insertmacro MUI_FUNCTION_DESCRIPTION_BEGIN
!insertmacro MUI_DESCRIPTION_TEXT ${UnrealDemolition} $(DESC_UnrealDemolition)
!insertmacro MUI_FUNCTION_DESCRIPTION_END

Section "Uninstall"
RMDir /r "$INSTDIR\UnrealDemolition\Help\*.*"
RMDir /r "$INSTDIR\UnrealDemolition\Maps\*.*"
RMDir /r "$INSTDIR\UnrealDemolition\Sounds\*.*"
RMDir /r "$INSTDIR\UnrealDemolition\StaticMeshes\*.*"
RMDir /r "$INSTDIR\UnrealDemolition\System\*.*"
RMDir /r "$INSTDIR\UnrealDemolition\Textures\*.*"
RMDir /r "$INSTDIR\UnrealDemolition\*.*"
RMDir /r "$INSTDIR\UnrealDemolition"
RMDIR /r "$SMPROGRAMS\UnrealDemolition" ; removes the start menu directory and files recursively.
SectionEnd