class UDBall extends KActor;
/**
 *  The ball Actor
 */
var Controller Bumper;
var bool bStarting, bEnding;
var ShadowProjector BallShadow;
var sound HitSound[7];
var int InactivityBallTimer;
var bool bTouched;
/////////////////////
// REPLICATION
struct TDStruct
{
    var Actor TDActor;
    var float TDDamage;
    var vector TDPos;
    var vector TDMomentum;
};

struct ClientKarmaCrap
{
    var vector Location;
    var vector Velocity;
    var vector AngularVelocity;
};

var array<TDStruct> DelayedTDs;
var ClientKarmaCrap CKC;
var Material Skin; //for replication purposes
var bool bUpdateCrapHack;
var bool bUpdateCrap;
/////////////////////

replication
{
    reliable if (Role == ROLE_Authority)
        Skin, CKC, bUpdateCrapHack;
}

simulated function PostNetReceive()
{
    bUpdateCrap = True;
}

simulated function bool KUpdateState(out KRigidBodyState newState)
{
    KGetRigidBodyState(newState);

    if ((Level.NetMode == NM_Client) && bUpdateCrap)
    {
        newState.Position = KRBVecFromVector(CKC.Location);
        newState.LinVel = KRBVecFromVector(CKC.Velocity);
        newState.AngVel = KRBVecFromVector(CKC.AngularVelocity * 0.001);
        bUpdateCrap = False;
        return True;
    }
    else
    {
        CKC.Location = KRBVecToVector(newState.Position);
        CKC.Velocity = KRBVecToVector(newState.LinVel);
        CKC.AngularVelocity = KRBVecToVector(newState.AngVel) * 1000.0;
        bUpdateCrapHack = bUpdateCrapHack;
        return False;
    }

    return False;
}

simulated function PostBeginPlay()
{
    BallShadow = Spawn(class'ShadowProjector', Self, '', Location);
    BallShadow.ShadowActor = Self;
    BallShadow.bBlobShadow = True;
    BallShadow.LightDirection = Normal(vect(1,1,6));
    BallShadow.LightDistance = 1300;
    BallShadow.MaxTraceDistance = 1000;
    BallShadow.CullDistance = 6000;
    BallShadow.InitShadow();

    Super.PostBeginPlay();
}

simulated function Touch(Actor Other)
{
    Super.Touch(Other);

    if (Other.IsA('PhysicsVolume'))
    {
        if (PhysicsVolume(Other).bPainCausing || PhysicsVolume(Other).bDestructive || PhysicsVolume(Other).bWaterVolume)
        {
            UDBallSpawn(Owner).KillBall();
            UDBallSpawn(Owner).SpawnBall();
            Level.Game.BroadcastLocalizedMessage(Class'UDCriticalEvent',2);
        }
    }
}

function KImpact(actor other, vector pos, vector impactVel, vector impactNorm)
{
    Super.KImpact(other, pos, impactVel, impactNorm);
    if (Other == None)
    {
        return;
    }

    if (Other.isA('Vehicle'))
    {
       bTouched = true;
       InactivityBallTimer = 0; // reset the reset timer
    }

    if ((Other.IsA('Vehicle')) && (Vehicle(Other).Controller != Bumper))
    {
        Bumper = Vehicle(Other).Controller;

    }

    if ((Other.IsA('KTire')) && (Vehicle(Other).Controller != Bumper))
    {
        Bumper = Vehicle(Other.Owner).Controller;
    }

    if (Other.IsA('Vehicle') || Other.IsA('KTire'))
    {
        PlaySound( HitSound[Rand(6)],, 1.5*TransientSoundVolume );
    }
    else
    {
        PlaySound( HitSound[Rand(6)],, 0.5*TransientSoundVolume );
    }
}

simulated function Destroyed()
{
    BallShadow.Destroy();
    Super.Destroyed();
}

simulated function Tick(float DeltaTime)
{
    local UDVolume Goal;

    if (bStarting)
    {
        SetDrawScale(DrawScale + 0.05);
        if (DrawScale >= 1.00)
            bStarting = False;
        foreach AllActors(class'UDVolume', Goal)
            Goal.Enable('Touch');
    }
    if (bEnding)
    {
        SetDrawScale(DrawScale - 0.07);
        if (DrawScale <= 0.05)
        {
            bEnding = False;
            Destroy();
        }
    }
}

defaultproperties
{
     HitSound(0)=Sound'ONSVehicleSounds-S.CollisionSounds.VehicleCollision01'
     HitSound(1)=Sound'ONSVehicleSounds-S.CollisionSounds.VehicleCollision02'
     HitSound(2)=Sound'ONSVehicleSounds-S.CollisionSounds.VehicleCollision03'
     HitSound(3)=Sound'ONSVehicleSounds-S.CollisionSounds.VehicleCollision04'
     HitSound(4)=Sound'ONSVehicleSounds-S.CollisionSounds.VehicleCollision05'
     HitSound(5)=Sound'ONSVehicleSounds-S.CollisionSounds.VehicleCollision06'
     HitSound(6)=Sound'ONSVehicleSounds-S.CollisionSounds.VehicleCollision07'
     StaticMesh=StaticMesh'UDStatics.newudsoccerball'
     bNoDelete=False
     bAcceptsProjectors=False
     RemoteRole=ROLE_SimulatedProxy
     NetPriority=2.000000
     bNetNotify=True
     Begin Object Class=KarmaParams Name=UDBallParams
         KMass=0.300000
         KBuoyancy=0.800000
         KStartEnabled=True
         bHighDetailOnly=False
         bClientOnly=False
         bKDoubleTickRate=True
         bKAllowRotate=True
         KFriction=0.300000
         KRestitution=0.800000
         KImpactThreshold=0.000000
     End Object
     KParams=KarmaParams'UnrealDemolition.UDBall.UDBallParams'

}
