class UDDemoBall extends TeamUD;

var(LoadingHints) private localized array<string> UDSHints;
var UDBallSpawn BallSpawn;      // The ball spawn.
var float OldScore;             // Old score before change.\

/**
 * Handle when a goal is scored with the ball
 * @param Controller the player who scored
 * @param UDBall the ball that went in
 * @param UDVolume the goal volume
 */
function ScoreBall(Controller Scorer, UDBall Ball, UDVolume Volume)
{
    local TeamInfo ScoringTeam;

    //
    if( ResetCountDown > 0 || IsInState('MatchOver'))
    {
        return;
    }

    // Missing values when a goal is registered means return
    if (Scorer == None || Ball == None || Volume == None)
    {
        return;
    }

    ScoringTeam = Level.Game.GameReplicationInfo.Teams[1-Volume.UDTeam];
    OldScore = ScoringTeam.Score;
    ScoringTeam.Score += 1.0;

    // Player scored in the opponent goal
    if (Scorer.PlayerReplicationInfo.Team == ScoringTeam)
    {
        Scorer.PlayerReplicationInfo.Score += 5.0;
        if (GameStats!=None)
        {
            GameStats.TeamScoreEvent(ScoringTeam.TeamIndex,1.0,"ball_tossed");
        }
    }
    // Player scored an own goal
    else
    {
        Scorer.PlayerReplicationInfo.Score -= 5.0;
    }

    if (ScoringTeam == Scorer.PlayerReplicationInfo.Team)
    {
        BroadCastLocalizedMessage(Class'UDCriticalEvent',0,Scorer.PlayerReplicationInfo);
    }
    else
    {
        BroadCastLocalizedMessage(Class'UDCriticalEvent',1,Scorer.PlayerReplicationInfo);
    }

    EndGameFocus = Scorer;
    AnnounceScore(ScoringTeam.TeamIndex);

    if ( (bOverTime || (GoalScore != 0)) && (Teams[Scorer.PlayerReplicationInfo.Team.TeamIndex].Score >= GoalScore) )
    {
        EndGame(Scorer.PlayerReplicationInfo,"teamscorelimit");
    }
    else if ( bOverTime )
    {
      // Goldengoal
        EndGame(Scorer.PlayerReplicationInfo,"timelimit");
    }

    if (!bGameEnded)
    {
        ResetCountDown = ResetTimeDelay;
    }
}


State MatchInProgress
{
    function Timer()
    {
        local Controller C;
        local Projectile Proj;
        local UDVech DrivenVehicle;

        Super.Timer();

        // reset the ball after five second when there is a goal
        if (ResetCountDown > 0)
        {
            ResetCountDown--;
            if ( ResetCountDown == 2)
            {
                if (BallSpawn != None)
                    BallSpawn.KillBall();
            }
            if ( ResetCountDown == 5 )
            {
                for ( C = Level.ControllerList; C != None; C = C.NextController )
                    if ( PlayerController(C) != None )
                        PlayerController(C).PlayStatusAnnouncement('NewRoundIn',1,true);
            }
            else if ( (ResetCountDown > 1) && (ResetCountDown < 4) )
                BroadcastLocalizedMessage(class'TimerMessage', ResetCountDown-1);
            else if (ResetCountDown == 1)
            {
                Teams[0].AI.ClearEnemies();
                Teams[1].AI.ClearEnemies();

                for (C = Level.ControllerList; C != None; C = C.NextController)
                {
                    DrivenVehicle = UDVech(C.Pawn);
                    if ( DrivenVehicle != None )
                    {
                        DrivenVehicle.KDriverLeave(true); // Force the driver out of the car
                        DrivenVehicle.Destroy();
                    }

                    if ( C.Pawn != None )
                    {
                        C.Pawn.Destroy();
                        C.PawnDied(None);
                    }
                }

                // reset all players position and rotation on the field for the next round
                for ( C = Level.ControllerList; C != None; C = C.NextController )
                {
                    if (C.PlayerReplicationInfo == None || C.PlayerReplicationInfo.bOnlySpectator)
                        continue;

                    RestartPlayerOldVehicle(C);
                }

                foreach DynamicActors(class'Projectile', Proj)
                    Proj.Destroy();

                if (BallSpawn != None)
                    BallSPawn.SpawnBall();

                ResetCountDown = 0;
            }
        }
        // reset the ball if after 20 seconds, no one touched the ball
        if (BallSpawn != none && BallSpawn.MyBall.bTouched)
        {
            if (BallSpawn.MyBall.InactivityBallTimer == 15)
            {
                BroadCastLocalizedMessage(Class'UDCriticalEvent', 3);
            }
            else if (BallSpawn.MyBall.InactivityBallTimer == 17)
            {
                BroadCastLocalizedMessage(Class'UDCriticalEvent', 4);
            }
            else if (BallSpawn.MyBall.InactivityBallTimer == 18)
            {
                BroadCastLocalizedMessage(Class'UDCriticalEvent', 5);
            }
            else if (BallSpawn.MyBall.InactivityBallTimer == 19)
            {
                BroadCastLocalizedMessage(Class'UDCriticalEvent', 6);
            }
            else if (BallSpawn.MyBall.InactivityBallTimer > 20)
            {
                // Reset the ball
                BallSpawn.KillBall();
                BallSPawn.SpawnBall();
                BallSpawn.MyBall.InactivityBallTimer = 0;
                BroadCastLocalizedMessage(Class'UDCriticalEvent',2);
            }
            BallSpawn.MyBall.InactivityBallTimer ++;
        }
        //Temporary fix for disappearing ball bug.
        //If the ball doesn't exist, forces a reset.
        if (BallSpawn.MyBall == none)
        {
            // Reset the ball
            BallSpawn.KillBall();
            BallSPawn.SpawnBall();
            BallSpawn.MyBall.InactivityBallTimer = 0;
            BroadCastLocalizedMessage(Class'UDCriticalEvent',2);
        }
    }
}

function RestartPlayerOldVehicle( Controller aPlayer )
{
    Super(xTeamGame).RestartPlayer(aPlayer);
    SpawnVehicle(aPlayer.Pawn);
}

function SpawnVehicle(Pawn P)
{
    local Vehicle EntryVehicle, V;

    if (P == none)
       return;

    //Used to hold data for spawning multiple vehicles.
    //Erased for time being until multi vehicles are replaced.
    if (P.PlayerReplicationInfo != None)
    {
        V = spawn(class'UDBike',,,P.Location, P.Rotation);
    }

    else // choose UDBike if no PRI
    {
        V = spawn(class'UDBike',,,P.Location, P.Rotation);
    }

    if (V != none)
    {
        // Sets the PreviousVehicleClass, needed to check what vehicle the player had last time
        if (P.PlayerReplicationInfo != None)
        {
            UDPRI(P.PlayerReplicationInfo).PreviousVehicleClass = V.class;
        }

        if (PlayerController(P.Controller) != None)
        {
            if (PlayerController(P.Controller).bBehindView == false)
            {
                PlayerController(P.Controller).ToggleBehindView();
                PlayerController(P.Controller).BehindView(True);
            }
        }

        // Copied code from PlayerController.ServerUse()
        EntryVehicle = V.FindEntryVehicle(P);
        if (EntryVehicle != None && EntryVehicle.TryToDrive(P))
        {
            return;
        }

        V.UsedBy(P);
        if ( P.Base != None )
        {
            P.Base.UsedBy(P);
        }

        P.Health-=1;
        P.Health+=1;

    }
    else
    {
        log ("BUG: NO VEHICLE!");
    }
}

// New bot class needed to give bots new PRI with PreviousVehicleClass
function Bot SpawnBot(optional string botName)
{
    local Bot NewBot;
    local RosterEntry Chosen;
    local UnrealTeamInfo BotTeam;

    BotTeam = GetBotTeam();
    Chosen = BotTeam.ChooseBotClass(botName);

    if (Chosen.PawnClass == None)
        Chosen.Init(); //amb
    NewBot = Spawn(Class'UDBot');

    if ( NewBot != None )
        InitializeBot(NewBot,BotTeam,Chosen);
    return NewBot;
}

function AnnounceScore(int ScoringTeam)
{
    local Controller C;
    local name ScoreSound;
    local int OtherTeam;

    if ( ScoringTeam == 1 )
        OtherTeam = 0;
    else
        OtherTeam = 1;

    if ( OldScore <= Teams[OtherTeam].Score )
    {
        if ( Teams[ScoringTeam].Score > Teams[OtherTeam].Score )
            ScoreSound = TakeLeadName[ScoringTeam];
        else
            ScoreSound = CaptureSoundName[ScoringTeam];
    }
    else
    {
        if ( OldScore <= Teams[OtherTeam].Score + 3 )
            ScoreSound = IncreaseLeadName[ScoringTeam];
        else
            ScoreSound = CaptureSoundName[ScoringTeam];
    }

    for ( C=Level.ControllerList; C!=None; C=C.NextController )
    {
        if ( C.IsA('PlayerController') )
            PlayerController(C).PlayStatusAnnouncement(ScoreSound,1,true);
    }
}

///////////////////////////////////////////////////////////
// Loads hints for loading screen.                       //
///////////////////////////////////////////////////////////
static function array<string> GetAllLoadHints(optional bool bThisClassOnly)
{
    local int i;
    local array<string> Hints;

    for ( i = 0; i < default.UDSHints.Length; i++ )
        Hints[Hints.Length] = default.UDSHints[i];

    return Hints;
}

///////////////////////////////////////////////////////////
// Default properties for the UD Soccer gametype.        //
///////////////////////////////////////////////////////////
defaultproperties
{
     // Custom Hints
     UDSHints(0)="Press %LEFT% or %RIGHT% to make your vehicle spin in mid-air."
     UDSHints(1)="Press %CROUCH% or %JUMP% to make your vehicle flip in mid-air."
     UDSHints(2)="Press [Roll Left] or [Roll right] to perform barrel rolls."
     UDSHints(3)="Press %JUMP% while on the ground to activate the handbrake."
     UDSHints(4)="Press %FIRE% to perform a jump. while in the air %FIRE% will make your vehicle stomp back to the ground."
     UDSHints(5)="Press %NEXTWEAPON% and %PREVWEAPON% to control the vehicle's camera zoom."
     UDSHints(6)="Pressing %ALTFIRE% will give you a sudden burst of speed."
     UDSHints(7)="Jumping and Boosting uses up your PSI. If you run out you'll be sorry."
     UDSHints(8)="Pick up PSI and Armor pickups to improve your vehicle and live longer."
     UDSHints(9)="%ALTFIRE% will flip your vehicle if you land on your back."
     UDSHints(10)="Pressing %ALTFIRE% repeatedly while your vehicle isn't upright will make your vehicle dance."
     UDSHints(11)="You can set what keys you can perform barrel rolls with in your input settings."
     UDSHints(12)="Killing other players will give you bonus points."
     UDSHints(13)="Trying to get too far out of a map can result in the blowing up of your vehicle."

     bScoreTeamKills=False
     bSpawnInTeamArea=True
     HUDType="UnrealDemolition.UDHUDDemoBall"
     MapPrefix="UDS"
     BeaconName="UDS"
     ResetTimeDelay=11
     GoalScore=10
     GameName="UD Soccer"
     Description="Team up with your friends and try to get the ball in the opposite goal!"
     ScreenShotName="UDHUD.intro.udsintro"
     Acronym="UDS"
}
